aboutsummaryrefslogtreecommitdiffstats
path: root/Alc/mixer.c
diff options
context:
space:
mode:
Diffstat (limited to 'Alc/mixer.c')
-rw-r--r--Alc/mixer.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/Alc/mixer.c b/Alc/mixer.c
index 6eaf4caf..71714c70 100644
--- a/Alc/mixer.c
+++ b/Alc/mixer.c
@@ -527,8 +527,8 @@ ALboolean MixSource(ALvoice *voice, ALsource *Source, ALCdevice *Device, ALsizei
{
ALfloat gain;
- /* Fade between the coefficients over 64 samples. */
- fademix = mini(DstBufferSize, 64);
+ /* Fade between the coefficients over 128 samples. */
+ fademix = mini(DstBufferSize, 128);
/* The new coefficients need to fade in completely
* since they're replacing the old ones. To keep the